@@ -1,79 +1,13 @@
 package Catalyst::Model::Search::ElasticSearch;
-$Catalyst::Model::Search::ElasticSearch::VERSION = '1.142520';
+$Catalyst::Model::Search::ElasticSearch::VERSION = '1.142550';
 use Moose;
 use namespace::autoclean;
 use Search::Elasticsearch;
 extends 'Catalyst::Model';
 
 
-# ABSTRACT: A simple Catalyst model to interface with L<Search::Elasticsearch>
+# ABSTRACT: A simple Catalyst model to interface with Search::Elasticsearch
 
-=head1 NAME
-
-Catalyst::Model::Search::ElasticSearch
-
-=cut
-
-=head1 SYNOPSIS
-
-    package My::App;
-    use strict;
-    use warnings;
-
-    use Catalyst;
-
-    our $VERSION = '0.01';
-    __PACKAGE__->config(
-      name            => 'Test::App',
-      'Model::Search' => {
-        nodes        => 'localhost:9200',
-        timeout      => 30,
-        max_requests => 10_000
-      }
-    );
-
-    __PACKAGE__->setup;
-
-
-    package My::App::Model::Search;
-    use Moose;
-    use namespace::autoclean;
-    extends 'Catalyst::Model::Search::ElasticSearch';
-
-    __PACKAGE__->meta->make_immutable;
-    1;
-
-    package My::App::Controller::Root;
-    use base 'Catalyst::Controller';
-    __PACKAGE__->config(namespace => '');
-
-    sub search : Local {
-      my ($self, $c) = @_;
-      my $params = $c->req->params;
-      my $search = $c->model('Search');
-      my $results = $search->search(
-        index => 'test',
-        type  => 'test',
-        body  => { query => { term => { schpongle => $params->{'q'} } } }
-      );
-      $c->stash( results => $results );
-
-    }
-
-
-=cut
-
-=head1 WARNING
-
-This is in very alpha stages.  More testing and production use are coming up, but be warned until then.
-
-=cut
-
-=head2 nodes
-
-A list of nodes to connect to.
-
-=cut
 
 has 'nodes' => (
   is      => 'rw',
@@ -81,11 +15,6 @@ has 'nodes' => (
   default => "localhost:9200",
 );
 
-=head2 transport
-
-The transport to use to interact with the Elasticsearch API.  See L<Search::Elasticsearch::Transport|Search::Elasticsearch::Transport> for options.
-
-=cut
 
 has 'transport' => (
   is      => 'rw',
@@ -93,11 +22,6 @@ has 'transport' => (
   default => "+Search::Elasticsearch::Transport",
 );
 
-=head2 _additional_opts
-
-Stores other key/value pairs to pass to L<Search::Elasticsearch|Search::Elasticsearch>
-
-=cut
 
 has '_additional_opts' => (
   is      => 'rw',
@@ -106,11 +30,6 @@ has '_additional_opts' => (
   default => sub { {} },
 );
 
-=head2 _es
-
-The L<Search::Elasticsearch|Search::Elasticsearch> object.
-
-=cut
 
 has '_es' => (
   is       => 'ro',
@@ -151,12 +70,131 @@ around BUILDARGS => sub {
   return $params;
 };
 
-=head1 SEE ALSO
-
-The Catalyst Advent article on integrating Elasticsearch into your app: L<http://www.catalystframework.org/calendar/2010/2>
-
-=cut
 
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Catalyst::Model::Search::ElasticSearch - A simple Catalyst model to interface with Search::Elasticsearch
+
+=head1 VERSION
+
+version 1.142550
+
+=head1 SYNOPSIS
+
+    package My::App;
+    use strict;
+    use warnings;
+
+    use Catalyst;
+
+    our $VERSION = '0.01';
+    __PACKAGE__->config(
+      name            => 'Test::App',
+      'Model::Search' => {
+        nodes           => 'localhost:9200',
+        request_timeout => 30,
+        max_requests    => 10_000
+      }
+    );
+
+    __PACKAGE__->setup;
+
+
+    package My::App::Model::Search;
+    use Moose;
+    use namespace::autoclean;
+    extends 'Catalyst::Model::Search::ElasticSearch';
+
+    __PACKAGE__->meta->make_immutable;
+    1;
+
+    package My::App::Controller::Root;
+    use base 'Catalyst::Controller';
+    __PACKAGE__->config(namespace => '');
+
+    sub search : Local {
+      my ($self, $c) = @_;
+      my $params = $c->req->params;
+      my $search = $c->model('Search');
+      my $results = $search->search(
+        index => 'test',
+        type  => 'test',
+        body  => { query => { term => { schpongle => $params->{'q'} } } }
+      );
+      $c->stash( results => $results );
+
+    }
+
+=head1 WARNING
+
+This is in very alpha stages.  More testing and production use are coming up, but be warned until then.
+
+=head1 CONFIGURATION PARAMETERS AND ATTRIBUTES
+
+=head2 nodes
+
+A list of nodes to connect to.
+
+=head2 transport
+
+The transport to use to interact with the Elasticsearch API.  See L<Search::Elasticsearch::Transport|Search::Elasticsearch::Transport> for options.
+
+=head2 _additional_opts
+
+Stores other key/value pairs to pass to L<Search::Elasticsearch|Search::Elasticsearch>.
+
+=head2 _es
+
+The L<Search::Elasticsearch|Search::Elasticsearch> object.
+
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+The Catalyst Advent article on integrating Elasticsearch into your app: L<http://www.catalystframework.org/calendar/2010/2>
+
+=item *
+
+L<Search::Elasticsearch|Search::Elasticsearch> - Elasticsearch interface this
+model provides access to
+
+=item *
+
+L<http://www.elasticsearch.org/> - Open Source Distributed Real Time Search and Analytics
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Devin Austin <dhoss@cpan.org>
+
+=item *
+
+Manfred Stock <mstock@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Devin Austin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
