@@ -8,10 +8,9 @@ our $VERSION = '0.01';
 __PACKAGE__->config(
   name            => 'Test::App',
   'Model::Search' => {
-    transport    => 'http',
-    servers      => 'localhost:9200',
-    timeout      => 30,
-    max_requests => 10_000
+    nodes           => 'localhost:9200',
+    request_timeout => 30,
+    max_requests    => 10_000
   }
 );
 
